@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 eNovance
+# Copyright 2013-2014 eNovance
 #
 # Author: Mehdi Abaakouk <mehdi.abaakouk@enovance.com>
 #
@@ -18,14 +17,14 @@
 """Rest alarm notifier."""
 
 import eventlet
+from oslo.config import cfg
+from oslo.serialization import jsonutils
 import requests
 import six.moves.urllib.parse as urlparse
 
-from oslo.config import cfg
-
 from ceilometer.alarm import notifier
-from ceilometer.openstack.common.gettextutils import _  # noqa
-from ceilometer.openstack.common import jsonutils
+from ceilometer.openstack.common import context
+from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
 
 LOG = log.getLogger(__name__)
@@ -44,6 +43,10 @@ REST_NOTIFIER_OPTS = [
                 help='Whether to verify the SSL Server certificate when '
                 'calling alarm action.'
                 ),
+    cfg.IntOpt('rest_notifier_max_retries',
+               default=0,
+               help='Number of retries for REST notifier',
+               ),
 
 ]
 
@@ -56,16 +59,21 @@ class RestAlarmNotifier(notifier.AlarmNotifier):
     @staticmethod
     def notify(action, alarm_id, previous, current, reason, reason_data,
                headers=None):
+        headers = headers or {}
+        if not headers.get('x-openstack-request-id'):
+            headers['x-openstack-request-id'] = context.generate_request_id()
+
         LOG.info(_(
             "Notifying alarm %(alarm_id)s from %(previous)s "
             "to %(current)s with action %(action)s because "
-            "%(reason)s") % ({'alarm_id': alarm_id, 'previous': previous,
-                              'current': current, 'action': action,
-                              'reason': reason}))
+            "%(reason)s. request-id: %(request_id)s") %
+            ({'alarm_id': alarm_id, 'previous': previous,
+              'current': current, 'action': action,
+              'reason': reason,
+              'request_id': headers['x-openstack-request-id']}))
         body = {'alarm_id': alarm_id, 'previous': previous,
                 'current': current, 'reason': reason,
                 'reason_data': reason_data}
-        headers = headers or {}
         headers['content-type'] = 'application/json'
         kwargs = {'data': jsonutils.dumps(body),
                   'headers': headers}
@@ -82,4 +90,12 @@ class RestAlarmNotifier(notifier.AlarmNotifier):
             if cert:
                 kwargs['cert'] = (cert, key) if key else cert
 
-        eventlet.spawn_n(requests.post, action.geturl(), **kwargs)
+        # FIXME(rhonjo): Retries are automatically done by urllib3 in requests
+        # library. However, there's no interval between retries in urllib3
+        # implementation. It will be better to put some interval between
+        # retries (future work).
+        max_retries = cfg.CONF.alarm.rest_notifier_max_retries
+        session = requests.Session()
+        session.mount(action.geturl(),
+                      requests.adapters.HTTPAdapter(max_retries=max_retries))
+        eventlet.spawn_n(session.post, action.geturl(), **kwargs)
