@@ -14,22 +14,15 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import cotyledon
-from cotyledon import oslo_config_glue
-from oslo_log import log
-
 from ceilometer import notification
+from ceilometer.openstack.common import service as os_service
 from ceilometer import service
 
-LOG = log.getLogger(__name__)
-
 
 def main():
-    conf = service.prepare_service()
-    conf.log_opt_values(LOG, log.DEBUG)
-
-    sm = cotyledon.ServiceManager()
-    sm.add(notification.NotificationService,
-           workers=conf.notification.workers, args=(conf,))
-    oslo_config_glue.setup(sm, conf)
-    sm.run()
+    service.prepare_service()
+    launcher = os_service.ProcessLauncher()
+    launcher.launch_service(
+        notification.NotificationService(),
+        workers=service.get_workers('notification'))
+    launcher.wait()
