@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 New Dream Network, LLC (DreamHost)
+# Copyright 2013 New Dream Network, LLC (DreamHost)
 #
 # Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #
@@ -18,28 +17,26 @@
 
 import sys
 
+from nova.compute import flavors
+from nova import conductor
 from nova import notifications
 from nova.openstack.common import log as logging
 from nova.openstack.common.notifier import api as notifier_api
+from nova import utils
+import six
+from stevedore import extension
 
 # HACK(dhellmann): Insert the nova version of openstack.common into
 # sys.modules as though it was the copy from ceilometer, so that when
 # we use modules from ceilometer below they do not re-define options.
 # use the real ceilometer base package
 import ceilometer  # noqa
+from ceilometer.compute.virt import inspector
+from ceilometer.openstack.common.gettextutils import _
+
 for name in ['openstack', 'openstack.common', 'openstack.common.log']:
     sys.modules['ceilometer.' + name] = sys.modules['nova.' + name]
 
-from nova.compute import flavors
-from nova import conductor
-from nova import utils
-
-from stevedore import extension
-
-from ceilometer.compute.virt import inspector
-from ceilometer.openstack.common.gettextutils import _  # noqa
-
-
 # This module runs inside the nova compute
 # agent, which only configures the "nova" logger.
 # We use a fake logger name in that namespace
@@ -100,7 +97,7 @@ class Instance(object):
     can pass it to the pollsters.
     """
     def __init__(self, context, info):
-        for k, v in info.iteritems():
+        for k, v in six.iteritems(info):
             if k == 'name':
                 setattr(self, 'OS-EXT-SRV-ATTR:instance_name', v)
             elif k == 'metadata':
