@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 Red Hat, Inc
+# Copyright 2012 Red Hat, Inc
 #
 # Author: Eoghan Glynn <eglynn@redhat.com>
 #
@@ -20,6 +19,7 @@
 """
 
 from oslo.config import cfg
+import oslo.messaging
 
 from ceilometer import plugin
 from ceilometer import sample
@@ -38,16 +38,15 @@ class ImageBase(plugin.NotificationBase):
     """Base class for image counting."""
 
     @staticmethod
-    def get_exchange_topics(conf):
-        """Return a sequence of ExchangeTopics defining the exchange and
-        topics to be connected for this plugin.
+    def get_targets(conf):
+        """Return a sequence of oslo.messaging.Target
+
+        This sequence is defining the exchange and topics to be connected for
+        this plugin.
         """
-        return [
-            plugin.ExchangeTopics(
-                exchange=conf.glance_control_exchange,
-                topics=set(topic + ".info"
-                           for topic in conf.notification_topics)),
-        ]
+        return [oslo.messaging.Target(topic=topic,
+                                      exchange=conf.glance_control_exchange)
+                for topic in conf.notification_topics]
 
 
 class ImageCRUDBase(ImageBase):
