@@ -1,6 +1,8 @@
 #
 # Copyright 2014 Cisco Systems,Inc.
 #
+# Author: Pradeep Kilambi <pkilambi@cisco.com>
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -13,7 +15,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from ceilometer.agent import plugin_base
+from ceilometer import neutron_client
+from ceilometer.openstack.common import log
+from ceilometer import plugin
+
+LOG = log.getLogger(__name__)
 
 
 # status map for converting metric status to volume int
@@ -21,17 +27,18 @@ STATUS = {
     'inactive': 0,
     'active': 1,
     'pending_create': 2,
-    'down': 3,
-    'created': 4,
-    'pending_update': 5,
-    'pending_delete': 6,
-    'error': 7,
 }
 
 
-class BaseServicesPollster(plugin_base.PollsterBase):
+class BaseServicesPollster(plugin.PollsterBase):
 
     FIELDS = []
+    nc = neutron_client.Client()
+
+    def _iter_cache(self, cache, meter_name, method):
+        if meter_name not in cache:
+            cache[meter_name] = list(method())
+        return iter(cache[meter_name])
 
     def extract_metadata(self, metric):
         return dict((k, metric[k]) for k in self.FIELDS)
