@@ -1,6 +1,8 @@
 #
 # Copyright 2014 Cisco Systems,Inc.
 #
+# Author: Pradeep Kilambi <pkilambi@cisco.com>
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -12,12 +14,11 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from oslo.utils import timeutils
 
-from oslo_log import log
-from oslo_utils import timeutils
-
-from ceilometer.i18n import _
 from ceilometer.network.services import base
+from ceilometer.openstack.common.gettextutils import _
+from ceilometer.openstack.common import log
 from ceilometer import sample
 
 LOG = log.getLogger(__name__)
@@ -46,15 +47,15 @@ class VPNServicesPollster(base.BaseServicesPollster):
             status = self.get_status_id(vpn['status'])
             if status == -1:
                 # unknown status, skip this sample
-                LOG.warning(_("Unknown status %(stat)s received on vpn "
-                              "%(id)s, skipping sample")
-                            % {'stat': vpn['status'], 'id': vpn['id']})
+                LOG.warn(_("Unknown status %(stat)s received on vpn %(id)s,"
+                           "skipping sample") % {'stat': vpn['status'],
+                                                 'id': vpn['id']})
                 continue
 
             yield sample.Sample(
                 name='network.services.vpn',
                 type=sample.TYPE_GAUGE,
-                unit='vpnservice',
+                unit='vpn',
                 volume=status,
                 user_id=None,
                 project_id=vpn['tenant_id'],
@@ -96,7 +97,7 @@ class IPSecConnectionsPollster(base.BaseServicesPollster):
             yield sample.Sample(
                 name='network.services.vpn.connections',
                 type=sample.TYPE_GAUGE,
-                unit='ipsec_site_connection',
+                unit='connection',
                 volume=1,
                 user_id=None,
                 project_id=conn['tenant_id'],
