@@ -24,6 +24,7 @@ from ceilometer.openstack.common import log
 
 
 CONF = cfg.CONF
+CONF.import_opt('http_timeout', 'ceilometer.service')
 
 
 LOG = log.getLogger(__name__)
@@ -98,7 +99,8 @@ class AnalyticsAPIBaseClient(object):
             'data': data,
             'verify': self.verify_ssl,
             'allow_redirects': False,
-            'cookies': cookies
+            'cookies': cookies,
+            'timeout': CONF.http_timeout,
         }
 
         return req_params
