@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Author: Doug Hellmann <doug.hellmann@dreamhost.com>
 #
@@ -18,25 +17,22 @@
 """Storage backend management
 """
 
-import six.moves.urllib.parse as urlparse
-
 from oslo.config import cfg
+from oslo.db import options as db_options
 import six
+import six.moves.urllib.parse as urlparse
 from stevedore import driver
 
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
 from ceilometer import utils
 
 
 LOG = log.getLogger(__name__)
 
-STORAGE_ENGINE_NAMESPACE = 'ceilometer.storage'
-
 OLD_STORAGE_OPTS = [
     cfg.StrOpt('database_connection',
                secret=True,
-               default=None,
                help='DEPRECATED - Database connection string.',
                ),
 ]
@@ -49,13 +45,20 @@ STORAGE_OPTS = [
                default=-1,
                help="Number of seconds that samples are kept "
                "in the database for (<= 0 means forever)."),
+    cfg.StrOpt('metering_connection',
+               default=None,
+               help='The connection string used to connect to the meteting '
+               'database. (if unset, connection is used)'),
+    cfg.StrOpt('alarm_connection',
+               default=None,
+               help='The connection string used to connect to the alarm '
+               'database. (if unset, connection is used)'),
 ]
 
 cfg.CONF.register_opts(STORAGE_OPTS, group='database')
 
-cfg.CONF.import_opt('connection',
-                    'ceilometer.openstack.common.db.sqlalchemy.session',
-                    group='database')
+db_options.set_defaults(cfg.CONF)
+cfg.CONF.import_opt('connection', 'oslo.db.options', group='database')
 
 
 class StorageBadVersion(Exception):
@@ -67,24 +70,28 @@ class StorageBadAggregate(Exception):
     code = 400
 
 
-def get_engine(conf):
-    """Load the configured engine and return an instance."""
+def get_connection_from_config(conf, purpose=None):
     if conf.database_connection:
         conf.set_override('connection', conf.database_connection,
                           group='database')
-    engine_name = urlparse.urlparse(conf.database.connection).scheme
-    LOG.debug(_('looking for %(name)r driver in %(namespace)r') % (
-              {'name': engine_name,
-               'namespace': STORAGE_ENGINE_NAMESPACE}))
-    mgr = driver.DriverManager(STORAGE_ENGINE_NAMESPACE,
-                               engine_name,
-                               invoke_on_load=True)
-    return mgr.driver
+    namespace = 'ceilometer.metering.storage'
+    url = conf.database.connection
+    if purpose:
+        namespace = 'ceilometer.%s.storage' % purpose
+        url = getattr(conf.database, '%s_connection' % purpose) or url
+    return get_connection(url, namespace)
 
 
-def get_connection(conf):
+def get_connection(url, namespace):
     """Return an open connection to the database."""
-    return get_engine(conf).get_connection(conf)
+    connection_scheme = urlparse.urlparse(url).scheme
+    # SqlAlchemy connections specify may specify a 'dialect' or
+    # 'dialect+driver'. Handle the case where driver is specified.
+    engine_name = connection_scheme.split('+')[0]
+    LOG.debug(_('looking for %(name)r driver in %(namespace)r') % (
+              {'name': engine_name, 'namespace': namespace}))
+    mgr = driver.DriverManager(namespace, engine_name)
+    return mgr.driver(url)
 
 
 class SampleFilter(object):
@@ -107,7 +114,7 @@ class SampleFilter(object):
                  end=None, end_timestamp_op=None,
                  resource=None, meter=None,
                  source=None, message_id=None,
-                 metaquery={}):
+                 metaquery=None):
         self.user = user
         self.project = project
         self.start = utils.sanitize_timestamp(start)
@@ -117,7 +124,7 @@ class SampleFilter(object):
         self.resource = resource
         self.meter = meter
         self.source = source
-        self.metaquery = metaquery
+        self.metaquery = metaquery or {}
         self.message_id = message_id
 
 
@@ -129,23 +136,25 @@ class EventFilter(object):
     :param event_type: the name of the event. None for all.
     :param message_id: the message_id of the event. None for all.
     :param traits_filter: the trait filter dicts, all of which are optional.
-                   This parameter is a list of dictionaries that specify
-                   trait values:
-                    {'key': <key>,
-                    'string': <value>,
-                    'integer': <value>,
-                    'datetime': <value>,
-                    'float': <value>,
-                    'op': <eq, lt, le, ne, gt or ge> }
+      This parameter is a list of dictionaries that specify trait values:
+
+    .. code-block:: python
+
+        {'key': <key>,
+        'string': <value>,
+        'integer': <value>,
+        'datetime': <value>,
+        'float': <value>,
+        'op': <eq, lt, le, ne, gt or ge> }
     """
 
     def __init__(self, start_time=None, end_time=None, event_type=None,
-                 message_id=None, traits_filter=[]):
+                 message_id=None, traits_filter=None):
         self.start_time = utils.sanitize_timestamp(start_time)
         self.end_time = utils.sanitize_timestamp(end_time)
         self.message_id = message_id
         self.event_type = event_type
-        self.traits_filter = traits_filter
+        self.traits_filter = traits_filter or []
 
     def __repr__(self):
         return ("<EventFilter(start_time: %s,"
