@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 eNovance
+# Copyright 2013-2014 eNovance
 #
 # Author: Julien Danjou <julien@danjou.info>
 #
@@ -15,20 +14,24 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import six.moves.urllib.parse as urlparse
 
+import anyjson
 import mock
+from oslo.config import fixture as fixture_config
+from oslotest import mockpatch
 import requests
+import six.moves.urllib.parse as urlparse
 
 from ceilometer.alarm import service
 from ceilometer.openstack.common import context
-from ceilometer.openstack.common.fixture import config
-from ceilometer.openstack.common import test
+from ceilometer.tests import base as tests_base
 
 
-DATA_JSON = ('{"current": "ALARM", "alarm_id": "foobar",'
-             ' "reason": "what ?", "reason_data": {"test": "test"},'
-             ' "previous": "OK"}')
+DATA_JSON = anyjson.loads(
+    '{"current": "ALARM", "alarm_id": "foobar",'
+    ' "reason": "what ?", "reason_data": {"test": "test"},'
+    ' "previous": "OK"}'
+)
 NOTIFICATION = dict(alarm_id='foobar',
                     condition=dict(threshold=42),
                     reason='what ?',
@@ -37,19 +40,23 @@ NOTIFICATION = dict(alarm_id='foobar',
                     current='ALARM')
 
 
-class TestAlarmNotifier(test.BaseTestCase):
+class TestAlarmNotifier(tests_base.BaseTestCase):
 
     def setUp(self):
         super(TestAlarmNotifier, self).setUp()
-        self.CONF = self.useFixture(config.Config()).conf
-        self.service = service.AlarmNotifierService('somehost', 'sometopic')
+        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.setup_messaging(self.CONF)
+        self.service = service.AlarmNotifierService()
+        self.useFixture(mockpatch.Patch(
+            'ceilometer.openstack.common.context.generate_request_id',
+            self._fake_generate_request_id))
 
     @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
     def test_init_host(self):
         # If we try to create a real RPC connection, init_host() never
         # returns. Mock it out so we can establish the service
         # configuration.
-        with mock.patch('ceilometer.openstack.common.rpc.create_connection'):
+        with mock.patch.object(self.service.rpc_server, 'start'):
             self.service.start()
 
     def test_notify_alarm(self):
@@ -80,8 +87,7 @@ class TestAlarmNotifier(test.BaseTestCase):
                                   {
                                       'actions': ['log://'],
                                       'alarm_id': 'foobar',
-                                      'condition': {'threshold': 42},
-                                  })
+                                      'condition': {'threshold': 42}})
 
     @staticmethod
     def _fake_spawn_n(func, *args, **kwargs):
@@ -94,17 +100,24 @@ class TestAlarmNotifier(test.BaseTestCase):
         notification['actions'] = [action]
         return notification
 
-    HTTP_HEADERS = {'content-type': 'application/json'}
+    HTTP_HEADERS = {'x-openstack-request-id': 'fake_request_id',
+                    'content-type': 'application/json'}
+
+    def _fake_generate_request_id(self):
+        return self.HTTP_HEADERS['x-openstack-request-id']
 
     def test_notify_alarm_rest_action_ok(self):
         action = 'http://host/action'
 
         with mock.patch('eventlet.spawn_n', self._fake_spawn_n):
-            with mock.patch.object(requests, 'post') as poster:
+            with mock.patch.object(requests.Session, 'post') as poster:
                 self.service.notify_alarm(context.get_admin_context(),
                                           self._notification(action))
-                poster.assert_called_with(action, data=DATA_JSON,
-                                          headers=self.HTTP_HEADERS)
+                poster.assert_called_with(action, data=mock.ANY,
+                                          headers=mock.ANY)
+                args, kwargs = poster.call_args
+                self.assertEqual(self.HTTP_HEADERS, kwargs['headers'])
+                self.assertEqual(DATA_JSON, anyjson.loads(kwargs['data']))
 
     def test_notify_alarm_rest_action_with_ssl_client_cert(self):
         action = 'https://host/action'
@@ -114,12 +127,15 @@ class TestAlarmNotifier(test.BaseTestCase):
                                group='alarm')
 
         with mock.patch('eventlet.spawn_n', self._fake_spawn_n):
-            with mock.patch.object(requests, 'post') as poster:
+            with mock.patch.object(requests.Session, 'post') as poster:
                 self.service.notify_alarm(context.get_admin_context(),
                                           self._notification(action))
-                poster.assert_called_with(action, data=DATA_JSON,
-                                          headers=self.HTTP_HEADERS,
+                poster.assert_called_with(action, data=mock.ANY,
+                                          headers=mock.ANY,
                                           cert=certificate, verify=True)
+                args, kwargs = poster.call_args
+                self.assertEqual(self.HTTP_HEADERS, kwargs['headers'])
+                self.assertEqual(DATA_JSON, anyjson.loads(kwargs['data']))
 
     def test_notify_alarm_rest_action_with_ssl_client_cert_and_key(self):
         action = 'https://host/action'
@@ -132,12 +148,15 @@ class TestAlarmNotifier(test.BaseTestCase):
                                group='alarm')
 
         with mock.patch('eventlet.spawn_n', self._fake_spawn_n):
-            with mock.patch.object(requests, 'post') as poster:
+            with mock.patch.object(requests.Session, 'post') as poster:
                 self.service.notify_alarm(context.get_admin_context(),
                                           self._notification(action))
-                poster.assert_called_with(action, data=DATA_JSON,
-                                          headers=self.HTTP_HEADERS,
+                poster.assert_called_with(action, data=mock.ANY,
+                                          headers=mock.ANY,
                                           cert=(certificate, key), verify=True)
+                args, kwargs = poster.call_args
+                self.assertEqual(self.HTTP_HEADERS, kwargs['headers'])
+                self.assertEqual(DATA_JSON, anyjson.loads(kwargs['data']))
 
     def test_notify_alarm_rest_action_with_ssl_verify_disable_by_cfg(self):
         action = 'https://host/action'
@@ -146,23 +165,29 @@ class TestAlarmNotifier(test.BaseTestCase):
                                group='alarm')
 
         with mock.patch('eventlet.spawn_n', self._fake_spawn_n):
-            with mock.patch.object(requests, 'post') as poster:
+            with mock.patch.object(requests.Session, 'post') as poster:
                 self.service.notify_alarm(context.get_admin_context(),
                                           self._notification(action))
-                poster.assert_called_with(action, data=DATA_JSON,
-                                          headers=self.HTTP_HEADERS,
+                poster.assert_called_with(action, data=mock.ANY,
+                                          headers=mock.ANY,
                                           verify=False)
+                args, kwargs = poster.call_args
+                self.assertEqual(self.HTTP_HEADERS, kwargs['headers'])
+                self.assertEqual(DATA_JSON, anyjson.loads(kwargs['data']))
 
     def test_notify_alarm_rest_action_with_ssl_verify_disable(self):
         action = 'https://host/action?ceilometer-alarm-ssl-verify=0'
 
         with mock.patch('eventlet.spawn_n', self._fake_spawn_n):
-            with mock.patch.object(requests, 'post') as poster:
+            with mock.patch.object(requests.Session, 'post') as poster:
                 self.service.notify_alarm(context.get_admin_context(),
                                           self._notification(action))
-                poster.assert_called_with(action, data=DATA_JSON,
-                                          headers=self.HTTP_HEADERS,
+                poster.assert_called_with(action, data=mock.ANY,
+                                          headers=mock.ANY,
                                           verify=False)
+                args, kwargs = poster.call_args
+                self.assertEqual(self.HTTP_HEADERS, kwargs['headers'])
+                self.assertEqual(DATA_JSON, anyjson.loads(kwargs['data']))
 
     def test_notify_alarm_rest_action_with_ssl_verify_enable_by_user(self):
         action = 'https://host/action?ceilometer-alarm-ssl-verify=1'
@@ -171,19 +196,22 @@ class TestAlarmNotifier(test.BaseTestCase):
                                group='alarm')
 
         with mock.patch('eventlet.spawn_n', self._fake_spawn_n):
-            with mock.patch.object(requests, 'post') as poster:
+            with mock.patch.object(requests.Session, 'post') as poster:
                 self.service.notify_alarm(context.get_admin_context(),
                                           self._notification(action))
-                poster.assert_called_with(action, data=DATA_JSON,
-                                          headers=self.HTTP_HEADERS,
+                poster.assert_called_with(action, data=mock.ANY,
+                                          headers=mock.ANY,
                                           verify=True)
+                args, kwargs = poster.call_args
+                self.assertEqual(self.HTTP_HEADERS, kwargs['headers'])
+                self.assertEqual(DATA_JSON, anyjson.loads(kwargs['data']))
 
     @staticmethod
     def _fake_urlsplit(*args, **kwargs):
         raise Exception("Evil urlsplit!")
 
     def test_notify_alarm_invalid_url(self):
-        with mock.patch('ceilometer.openstack.common.network_utils.urlsplit',
+        with mock.patch('oslo.utils.netutils.urlsplit',
                         self._fake_urlsplit):
             LOG = mock.MagicMock()
             with mock.patch('ceilometer.alarm.service.LOG', LOG):
@@ -207,3 +235,27 @@ class TestAlarmNotifier(test.BaseTestCase):
                     'condition': {'threshold': 42},
                 })
             self.assertTrue(LOG.error.called)
+
+    def test_notify_alarm_trust_action(self):
+        action = 'trust+http://trust-1234@host/action'
+        url = 'http://host/action'
+
+        client = mock.MagicMock()
+        client.auth_token = 'token_1234'
+        headers = {'X-Auth-Token': 'token_1234'}
+        headers.update(self.HTTP_HEADERS)
+
+        self.useFixture(mockpatch.Patch('keystoneclient.v3.client.Client',
+                                        lambda **kwargs: client))
+
+        with mock.patch('eventlet.spawn_n', self._fake_spawn_n):
+            with mock.patch.object(requests.Session, 'post') as poster:
+                self.service.notify_alarm(context.get_admin_context(),
+                                          self._notification(action))
+                headers = {'X-Auth-Token': 'token_1234'}
+                headers.update(self.HTTP_HEADERS)
+                poster.assert_called_with(
+                    url, data=mock.ANY, headers=mock.ANY)
+                args, kwargs = poster.call_args
+                self.assertEqual(headers, kwargs['headers'])
+                self.assertEqual(DATA_JSON, anyjson.loads(kwargs['data']))
