@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 Intel
+# Copyright 2013 Intel
 #
 # Author: Shuangtai Tian <Shuangtai.tian@intel.com>
 #
@@ -21,8 +20,9 @@ notification events.
 
 import copy
 
+from oslotest import base
+
 from ceilometer.compute.notifications import cpu
-from ceilometer.openstack.common import test
 
 
 METRICS_UPDATE = {
@@ -89,7 +89,7 @@ RES_ID = '%s_%s' % (METRICS_UPDATE['payload']['host'],
                     METRICS_UPDATE['payload']['nodename'])
 
 
-class TestMetricsNotifications(test.BaseTestCase):
+class TestMetricsNotifications(base.BaseTestCase):
     def _process_notification(self, ic):
         self.assertIn(METRICS_UPDATE['event_type'],
                       ic.event_types)
@@ -100,7 +100,7 @@ class TestMetricsNotifications(test.BaseTestCase):
     def test_compute_metrics(self):
         ERROR_METRICS = copy.copy(METRICS_UPDATE)
         ERROR_METRICS['payload'] = {"metric_err": []}
-        ic = cpu.CpuFrequency()
+        ic = cpu.CpuFrequency(None)
         info = ic._get_sample(METRICS_UPDATE, 'cpu.frequency')
         info_none = ic._get_sample(METRICS_UPDATE, 'abc.efg')
         info_error = ic._get_sample(ERROR_METRICS, 'cpu.frequency')
@@ -109,51 +109,51 @@ class TestMetricsNotifications(test.BaseTestCase):
         self.assertIsNone(info_error)
 
     def test_compute_cpu_frequency(self):
-        c = self._process_notification(cpu.CpuFrequency())
+        c = self._process_notification(cpu.CpuFrequency(None))
         self.assertEqual('compute.node.cpu.frequency', c.name)
         self.assertEqual(1600, c.volume)
 
     def test_compute_cpu_user_time(self):
-        c = self._process_notification(cpu.CpuUserTime())
+        c = self._process_notification(cpu.CpuUserTime(None))
         self.assertEqual('compute.node.cpu.user.time', c.name)
         self.assertEqual(17421440000000L, c.volume)
 
     def test_compute_cpu_kernel_time(self):
-        c = self._process_notification(cpu.CpuKernelTime())
+        c = self._process_notification(cpu.CpuKernelTime(None))
         self.assertEqual('compute.node.cpu.kernel.time', c.name)
         self.assertEqual(7852600000000L, c.volume)
 
     def test_compute_cpu_idle_time(self):
-        c = self._process_notification(cpu.CpuIdleTime())
+        c = self._process_notification(cpu.CpuIdleTime(None))
         self.assertEqual('compute.node.cpu.idle.time', c.name)
         self.assertEqual(1307374400000000L, c.volume)
 
     def test_compute_cpu_iowait_time(self):
-        c = self._process_notification(cpu.CpuIowaitTime())
+        c = self._process_notification(cpu.CpuIowaitTime(None))
         self.assertEqual('compute.node.cpu.iowait.time', c.name)
         self.assertEqual(11697470000000L, c.volume)
 
     def test_compute_cpu_kernel_percent(self):
-        c = self._process_notification(cpu.CpuKernelPercent())
+        c = self._process_notification(cpu.CpuKernelPercent(None))
         self.assertEqual('compute.node.cpu.kernel.percent', c.name)
         self.assertEqual(0.5841204961898534, c.volume)
 
     def test_compute_cpu_idle_percent(self):
-        c = self._process_notification(cpu.CpuIdlePercent())
+        c = self._process_notification(cpu.CpuIdlePercent(None))
         self.assertEqual('compute.node.cpu.idle.percent', c.name)
         self.assertEqual(97.24985141658965, c.volume)
 
     def test_compute_cpu_user_percent(self):
-        c = self._process_notification(cpu.CpuUserPercent())
+        c = self._process_notification(cpu.CpuUserPercent(None))
         self.assertEqual('compute.node.cpu.user.percent', c.name)
         self.assertEqual(1.2959045637294348, c.volume)
 
     def test_compute_cpu_iowait_percent(self):
-        c = self._process_notification(cpu.CpuIowaitPercent())
+        c = self._process_notification(cpu.CpuIowaitPercent(None))
         self.assertEqual('compute.node.cpu.iowait.percent', c.name)
         self.assertEqual(0.8701235234910634, c.volume)
 
     def test_compute_cpu_percent(self):
-        c = self._process_notification(cpu.CpuPercent())
+        c = self._process_notification(cpu.CpuPercent(None))
         self.assertEqual('compute.node.cpu.percent', c.name)
         self.assertEqual(2.7501485834103515, c.volume)
