@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Author: Julien Danjou <julien@danjou.info>
 #
@@ -17,12 +16,13 @@
 # under the License.
 
 import mock
+from oslo.config import fixture as fixture_config
+from oslotest import base
+from oslotest import mockpatch
 
 from ceilometer.central import manager
 from ceilometer.image import glance
 from ceilometer.openstack.common import context
-from ceilometer.openstack.common.fixture import mockpatch
-from ceilometer.openstack.common import test
 
 IMAGE_LIST = [
     type('Image', (object,),
@@ -104,21 +104,68 @@ IMAGE_LIST = [
           u'size': 2048}),
 ]
 
+ENDPOINT = 'end://point'
+
 
 class _BaseObject(object):
     pass
 
 
+class FakeGlanceClient(object):
+    class images(object):
+        pass
+
+
 class TestManager(manager.AgentManager):
 
     def __init__(self):
         super(TestManager, self).__init__()
-        self.keystone = None
+        self.keystone = mock.Mock()
+        self.keystone.service_catalog.get_endpoints = mock.Mock(
+            return_value={'image': mock.ANY})
 
 
-class TestImagePollster(test.BaseTestCase):
+class TestImagePollsterPageSize(base.BaseTestCase):
 
-    def fake_get_glance_client(self, ksclient):
+    def fake_get_glance_client(self, ksclient, endpoint):
+        glanceclient = FakeGlanceClient()
+        glanceclient.images.list = mock.MagicMock(return_value=IMAGE_LIST)
+        return glanceclient
+
+    @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
+    def setUp(self):
+        super(TestImagePollsterPageSize, self).setUp()
+        self.context = context.get_admin_context()
+        self.manager = TestManager()
+        self.useFixture(mockpatch.PatchObject(
+            glance._Base, 'get_glance_client',
+            side_effect=self.fake_get_glance_client))
+        self.CONF = self.useFixture(fixture_config.Config()).conf
+
+    def _do_test_iter_images(self, page_size=0):
+        self.CONF.set_override("glance_page_size", page_size)
+        images = list(glance.ImagePollster().
+                      _iter_images(self.manager.keystone, {}, ENDPOINT))
+        kwargs = {}
+        if page_size > 0:
+            kwargs['page_size'] = page_size
+        FakeGlanceClient.images.list.assert_called_with(
+            filters={'is_public': False}, **kwargs)
+        self.assertEqual(len(set(image.id for image in images)), len(images))
+
+    def test_page_size(self):
+        self._do_test_iter_images(100)
+
+    def test_page_size_default(self):
+        self._do_test_iter_images()
+
+    def test_page_size_negative_number(self):
+        self._do_test_iter_images(-1)
+
+
+class TestImagePollster(base.BaseTestCase):
+
+    def fake_get_glance_client(self, ksclient, endpoint):
         glanceclient = _BaseObject()
         setattr(glanceclient, "images", _BaseObject())
         setattr(glanceclient.images,
@@ -134,30 +181,37 @@ class TestImagePollster(test.BaseTestCase):
             glance._Base, 'get_glance_client',
             side_effect=self.fake_get_glance_client))
 
+    def test_default_discovery(self):
+        pollster = glance.ImagePollster()
+        self.assertEqual('endpoint:image', pollster.default_discovery)
+
     def test_iter_images(self):
-        # Tests whether the iter_images method returns an unique image
+        # Tests whether the iter_images method returns a unique image
         # list when there is nothing in the cache
         images = list(glance.ImagePollster().
-                      _iter_images(self.manager.keystone, {}))
+                      _iter_images(self.manager.keystone, {}, ENDPOINT))
         self.assertEqual(len(set(image.id for image in images)), len(images))
 
     def test_iter_images_cached(self):
         # Tests whether the iter_images method returns the values from
         # the cache
-        cache = {'images': []}
+        cache = {'%s-images' % ENDPOINT: []}
         images = list(glance.ImagePollster().
-                      _iter_images(self.manager.keystone, cache))
+                      _iter_images(self.manager.keystone, cache,
+                                   ENDPOINT))
         self.assertEqual([], images)
 
     def test_image(self):
-        samples = list(glance.ImagePollster().get_samples(self.manager, {}))
+        samples = list(glance.ImagePollster().get_samples(self.manager, {},
+                                                          [ENDPOINT]))
         self.assertEqual(3, len(samples))
         for sample in samples:
             self.assertEqual(1, sample.volume)
 
     def test_image_size(self):
         samples = list(glance.ImageSizePollster().get_samples(self.manager,
-                                                              {}))
+                                                              {},
+                                                              [ENDPOINT]))
         self.assertEqual(3, len(samples))
         for image in IMAGE_LIST:
             self.assertTrue(
@@ -165,10 +219,12 @@ class TestImagePollster(test.BaseTestCase):
                         samples)))
 
     def test_image_get_sample_names(self):
-        samples = list(glance.ImagePollster().get_samples(self.manager, {}))
+        samples = list(glance.ImagePollster().get_samples(self.manager, {},
+                                                          [ENDPOINT]))
         self.assertEqual(set(['image']), set([s.name for s in samples]))
 
     def test_image_size_get_sample_names(self):
         samples = list(glance.ImageSizePollster().get_samples(self.manager,
-                                                              {}))
+                                                              {},
+                                                              [ENDPOINT]))
         self.assertEqual(set(['image.size']), set([s.name for s in samples]))
