@@ -1,6 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 eNovance
+# Copyright 2013-2014 eNovance
 #
 # Author: Julien Danjou <julien@danjou.info>
 #
@@ -22,10 +21,10 @@ import datetime
 
 import mock
 import msgpack
+from oslo.config import fixture as fixture_config
+from oslo.utils import netutils
+from oslotest import base
 
-from ceilometer.openstack.common.fixture import config
-from ceilometer.openstack.common import network_utils
-from ceilometer.openstack.common import test
 from ceilometer.publisher import udp
 from ceilometer.publisher import utils
 from ceilometer import sample
@@ -34,7 +33,7 @@ from ceilometer import sample
 COUNTER_SOURCE = 'testsource'
 
 
-class TestUDPPublisher(test.BaseTestCase):
+class TestUDPPublisher(base.BaseTestCase):
     test_data = [
         sample.Sample(
             name='test',
@@ -111,7 +110,7 @@ class TestUDPPublisher(test.BaseTestCase):
 
     def setUp(self):
         super(TestUDPPublisher, self).setUp()
-        self.CONF = self.useFixture(config.Config()).conf
+        self.CONF = self.useFixture(fixture_config.Config()).conf
         self.CONF.publisher.metering_secret = 'not-so-secret'
 
     def test_published(self):
@@ -119,7 +118,7 @@ class TestUDPPublisher(test.BaseTestCase):
         with mock.patch('socket.socket',
                         self._make_fake_socket(self.data_sent)):
             publisher = udp.UDPPublisher(
-                network_utils.urlsplit('udp://somehost'))
+                netutils.urlsplit('udp://somehost'))
         publisher.publish_samples(None,
                                   self.test_data)
 
@@ -153,6 +152,6 @@ class TestUDPPublisher(test.BaseTestCase):
         with mock.patch('socket.socket',
                         self._make_broken_socket):
             publisher = udp.UDPPublisher(
-                network_utils.urlsplit('udp://localhost'))
+                netutils.urlsplit('udp://localhost'))
         publisher.publish_samples(None,
                                   self.test_data)
