@@ -1,6 +1,8 @@
 #
 # Copyright 2014 Red Hat, Inc
 #
+# Author: Nejc Saje <nsaje@redhat.com>
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -18,10 +20,10 @@ import keyword
 import math
 import re
 
-from oslo_log import log
 import six
 
-from ceilometer.i18n import _
+from ceilometer.openstack.common.gettextutils import _
+from ceilometer.openstack.common import log
 from ceilometer import sample
 from ceilometer import transformer
 
@@ -35,8 +37,6 @@ class ArithmeticTransformer(transformer.TransformerBase):
     over one or more meters and/or their metadata.
     """
 
-    grouping_keys = ['resource_id']
-
     meter_name_re = re.compile(r'\$\(([\w\.\-]+)\)')
 
     def __init__(self, target=None, **kwargs):
@@ -45,7 +45,7 @@ class ArithmeticTransformer(transformer.TransformerBase):
         self.target = target
         self.expr = target.get('expr', '')
         self.expr_escaped, self.escaped_names = self.parse_expr(self.expr)
-        self.required_meters = list(self.escaped_names.values())
+        self.required_meters = self.escaped_names.values()
         self.misconfigured = len(self.required_meters) == 0
         if not self.misconfigured:
             self.reference_meter = self.required_meters[0]
@@ -54,8 +54,8 @@ class ArithmeticTransformer(transformer.TransformerBase):
             self.cache = collections.defaultdict(dict)
             self.latest_timestamp = None
         else:
-            LOG.warning(_('Arithmetic transformer must use at least one'
-                        ' meter in expression \'%s\''), self.expr)
+            LOG.warn(_('Arithmetic transformer must use at least one'
+                       ' meter in expression \'%s\''), self.expr)
 
     def _update_cache(self, _sample):
         """Update the cache with the latest sample."""
@@ -92,8 +92,8 @@ class ArithmeticTransformer(transformer.TransformerBase):
                 resource_metadata=reference_sample.resource_metadata
             )
         except Exception as e:
-            LOG.warning(_('Unable to evaluate expression %(expr)s: %(exc)s'),
-                        {'expr': self.expr, 'exc': e})
+            LOG.warn(_('Unable to evaluate expression %(expr)s: %(exc)s'),
+                     {'expr': self.expr, 'exc': str(e)})
 
     def handle_sample(self, context, _sample):
         self._update_cache(_sample)
@@ -101,14 +101,15 @@ class ArithmeticTransformer(transformer.TransformerBase):
 
     def flush(self, context):
         new_samples = []
-        cache_clean_list = []
         if not self.misconfigured:
             for resource_id in self.cache:
                 if self._check_requirements(resource_id):
                     new_samples.append(self._calculate(resource_id))
-                    cache_clean_list.append(resource_id)
-            for res_id in cache_clean_list:
-                self.cache.pop(res_id)
+                else:
+                    LOG.warn(_('Unable to perform calculation, not all of '
+                               '{%s} are present'),
+                             ', '.join(self.required_meters))
+            self.cache.clear()
         return new_samples
 
     @classmethod
@@ -120,7 +121,7 @@ class ArithmeticTransformer(transformer.TransformerBase):
                  the translation of meter names into Python identifiers
         """
 
-        class Replacer(object):
+        class Replacer():
             """Replaces matched meter names with escaped names.
 
             If the meter name is not followed by parameter access in the
