@@ -1,6 +1,4 @@
-#!/usr/bin/env python
-#
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
+    # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
 #
@@ -15,27 +13,26 @@
 import os
 import sys
 
-from oslo_config import cfg
+from oslo.config import cfg
 
 from ceilometer import storage
 
-
 def main(argv):
     cfg.CONF([], project='ceilometer')
-    if os.getenv("CEILOMETER_TEST_STORAGE_URL", "").startswith("hbase://"):
+    if os.getenv("CEILOMETER_TEST_HBASE_URL"):
         url = ("%s?table_prefix=%s" %
-               (os.getenv("CEILOMETER_TEST_STORAGE_URL"),
+               (os.getenv("CEILOMETER_TEST_HBASE_URL"),
                 os.getenv("CEILOMETER_TEST_HBASE_TABLE_PREFIX", "test")))
         conn = storage.get_connection(url, 'ceilometer.metering.storage')
-        event_conn = storage.get_connection(url, 'ceilometer.event.storage')
+        alarm_conn = storage.get_connection(url, 'ceilometer.alarm.storage')
         for arg in argv:
             if arg == "--upgrade":
                 conn.upgrade()
-                event_conn.upgrade()
+                alarm_conn.upgrade()
             if arg == "--clear":
                 conn.clear()
-                event_conn.clear()
+                alarm_conn.clear()
 
 
 if __name__ == '__main__':
-    main(sys.argv[1:])
+    main(sys.argv[1:])
\ No newline at end of file
